/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:bloc/bloc.dart';
import 'package:equatable/equatable.dart';
import 'package:flutter/foundation.dart';
import 'package:logging/logging.dart';
part 'visual_state.dart';

class VisualCubit extends Cubit<VisualState> {
  final log = Logger('VisualCubit');

  VisualCubit(VisualState visualState)
      : super(VisualState(mode: visualState.mode, contrast: visualState.contrast, fontSize: visualState.fontSize));

  setModeLight() {
    emit(VisualState.from(state, mode: Mode.light));
    log.info("setModeLight() - state: " + state.toString());
  }

  setModeDark() {
    emit(VisualState.from(state, mode: Mode.dark));
    log.info("setModeDark() - state: " + state.toString());
  }

  setContrastStd() {
    emit(VisualState.from(state, contrast: Contrast.std));
    log.info("setContrastStd() - state: " + state.toString());
  }

  setContrastHigh() {
    emit(VisualState.from(state, contrast: Contrast.high));
    log.info("setContrastHigh() - state: " + state.toString());
  }

  setFontSizeBig() {
    emit(VisualState.from(state, fontSize: FontSize.big));
    log.info("setFontSizeBig() - state: " + state.toString());
  }

  setFontSizeStd() {
    emit(VisualState.from(state, fontSize: FontSize.std));
    log.info("setFontSizeStd() - state: " + state.toString());
  }
}
