/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

part of 'visual_cubit.dart';

enum FontSize { std, big }

enum Mode { light, dark }

enum Contrast { std, high }

class VisualState extends Equatable {
  final Mode _mode;
  final Contrast _contrast;
  final FontSize _fontSize;

  get mode => _mode;

  get contrast => _contrast;

  get fontSize => _fontSize;

  const VisualState({@required mode, @required contrast, @required fontSize})
      : this._mode = mode,
        this._contrast = contrast,
        this._fontSize = fontSize;

  factory VisualState.from(VisualState visualState, {Mode mode, Contrast contrast, FontSize fontSize}) {
    return VisualState(
        mode: mode ?? visualState._mode, contrast: contrast ?? visualState._contrast, fontSize: fontSize ?? visualState._fontSize);
  }

  factory VisualState.std() {
    return VisualState(mode: Mode.light, contrast: Contrast.std, fontSize: FontSize.std);
  }

  @override
  List<Object> get props => [mode, contrast, fontSize];

  Map<String, dynamic> _toMap() => {
    'mode': mode,
    'contrast': contrast,
    'fontSize': fontSize
  };

  @override
  String toString() {
    return _toMap().toString();
  }
}
