/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:surec_app/cache/fs_cache_exception.dart';
import 'package:surec_app/cache/fs_audio_cache.dart';
import 'package:surec_app/cache/fs_image_and_video_cache.dart';
import 'package:surec_app/cache/fs_note_cache.dart';


class CacheHolder {
  static final CacheHolder _singleton = CacheHolder._internal();
  CacheHolder._internal();

  static FSImageAndVideoCache _imageAndVideoCache;
  static FSAudioCache _audioCache;
  static FSNoteCache _noteCache;

  factory CacheHolder() {
    return _singleton;
  }

  bool isInitializedImageAndVideoCache() {
    return _imageAndVideoCache != null;
  }

  bool isInitializedAudioCache() {
    return _audioCache != null;
  }

  bool isInitializedNoteCache() {
    return _noteCache != null;
  }

  FSImageAndVideoCache getImageAndVideoCache() {
    return _imageAndVideoCache;
  }

  FSAudioCache getAudioCache() {
    return _audioCache;
  }

  FSNoteCache getNoteCache() {
    return _noteCache;
  }

  void initializeImageAndVideoCache(FSImageAndVideoCache imageAndVideoCache) {
    if(imageAndVideoCache == null) {
      throw FSCacheException(FSCacheExceptionCode.INVALID_ARGUMENT, explanation: "can not initialize image and video cache with null");
    }
    if(_imageAndVideoCache != null) {
      throw FSCacheException(FSCacheExceptionCode.ALREADY_INITIALIZED, explanation: "image and video cache is already initilized");
    }
    _imageAndVideoCache = imageAndVideoCache;
  }

  void initializeAudioCache(FSAudioCache audioCache) {
    if(audioCache == null) {
      throw FSCacheException(FSCacheExceptionCode.INVALID_ARGUMENT, explanation: "can not initialize audio cache with null");
    }
    if(_audioCache != null) {
      throw FSCacheException(FSCacheExceptionCode.ALREADY_INITIALIZED, explanation: "audio cache is already initilized");
    }
    _audioCache = audioCache;
  }

  void initializeNoteCache(FSNoteCache noteCache) {
    if(noteCache == null) {
      throw FSCacheException(FSCacheExceptionCode.INVALID_ARGUMENT, explanation: "can not initialize note cache with null");
    }
    if(_noteCache != null) {
      throw FSCacheException(FSCacheExceptionCode.ALREADY_INITIALIZED, explanation: "note cache is already initilized");
    }
    _noteCache = noteCache;
  }

}



