/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'dart:io';
import 'package:logging/logging.dart';
import 'package:path/path.dart' as p;
import 'fs_cache_exception.dart';


class FSCache {
  final log = Logger('FSCache');

  var _cachePath;
  var _knownItemsInCacheDirectory = Map<String, String>();


  FSCache(this._cachePath) {
    prepareFSCache(_cachePath);
  }

  bool prepareFSCache(String cachePath) {
    try {
      var cacheDirectory = Directory(cachePath);
      cacheDirectory.createSync(recursive: true);
      if (cacheDirectory.existsSync()) {
        return true;
      }
    } catch (e, s) {
      final message = "could not create cache dir $cachePath\n$e\n$s";
      log.severe(message);
    }
    return false;
  }

  get cachePath => _cachePath;

  void resetKnownCacheItems(knownItemsInCacheDirectory) {
    _knownItemsInCacheDirectory = Map<String, String>();
  }

  void initializeKnownCacheItems(knownItemsInCacheDirectory) {
    _knownItemsInCacheDirectory = knownItemsInCacheDirectory;
  }

  String putIfAbsentIntoKnownCacheItems(strippedName, basename) {
    return _knownItemsInCacheDirectory.putIfAbsent(strippedName, () => basename);
  }

  String getPathToKnownItemForStrippedName(String strippedName) {
    if (_knownItemsInCacheDirectory.containsKey(strippedName)) {
      return p.join(cachePath, _knownItemsInCacheDirectory[strippedName]);
    }
  }

  String getTempItemCapturePathWithNameForSuffix(String suffix) {
    var tempfilename = "$timestamp$suffix";
    return p.join(cachePath, tempfilename);
  }

  static String getTempItemCapturePathWithNameForCachePathAndSuffix(String cachePath, String suffix) {
    var tempfilename = "$timestamp$suffix";
    return p.join(cachePath, tempfilename);
  }

  static get timestamp => DateTime.now().millisecondsSinceEpoch.toString();

  String fileTypeOfBasenameForValidFileTypes(String basename, List<String> validFileTypes, String tmpSuffix) {
    var _validFileTypes = validFileTypes.map((fileType) => fileType.toLowerCase());
    var _tmpSuffix = tmpSuffix.toLowerCase();
    var _basename = basename.toLowerCase();

    for(var fileType in _validFileTypes) {
      if(_basename.endsWith(fileType) | _basename.endsWith("$fileType$_tmpSuffix") ) {
        return fileType;
      }
    }
  }

  String strippedNameForFileTypeAndTmpSuffix(String basename, fileType, String tmpSuffix) {
    var _fileType = fileType.toLowerCase();
    var _tmpSuffix = tmpSuffix.toLowerCase();
    var _basename = basename.toLowerCase();
    var strippedName ;
    if (_basename.endsWith(_tmpSuffix)) {
      strippedName = basename.substring(0, basename.length - _tmpSuffix.length);
    } else {
      strippedName = basename;
    }
    strippedName = strippedName.substring(0, strippedName.length - _fileType.length);
    return strippedName;
  }
}