/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:surec_app/surecord/surecord_blocmeta.dart';
import 'package:surec_app/surecord/surecord_blocutil.dart';
import 'package:surec_app/surecord/surecord_exception.dart';
import 'package:surec_app/filter/filter.dart';

class BlocSuRecordAdapterAttribute implements BaseAdapterAttribute {
  final _value;
  const BlocSuRecordAdapterAttribute._internal(this._value);
  toString() => 'SuRecordFileAdapterAttribute.$_value';

  static const tags = const BlocSuRecordAdapterAttribute._internal('tags');
  static const refs = const BlocSuRecordAdapterAttribute._internal('refs');
  static const firstLocalConfirmation = const BlocSuRecordAdapterAttribute._internal('firstLocalConfirmation');
  static const lastModification = const BlocSuRecordAdapterAttribute._internal('lastModification');
}

extension BlocSuRecordAdapterAttributeType on BlocSuRecordAdapterAttribute {
  static const _typeMap = {
    BlocSuRecordAdapterAttribute.tags : RecordAdapterType.stringList,
    BlocSuRecordAdapterAttribute.refs : RecordAdapterType.stringList,
    BlocSuRecordAdapterAttribute.firstLocalConfirmation : RecordAdapterType.int,
    BlocSuRecordAdapterAttribute.lastModification : RecordAdapterType.int
  };

  RecordAdapterType type() {
    return _typeMap[this];
  }
}

// --------------------------------------------------------------

class BlocSuRecordAdapter extends BaseAdapter {

  BlocSuRecord _blocSuRecord;
  BlocSuRecordAdapter(this._blocSuRecord);

  double getDoubleAttribute(BaseAdapterAttribute attr) {
    switch(attr) {
      default:
        throw SuRecordException(SuRecordExceptionCode.INVALID_ARGUMENT,explanation: "");
    }
  }

  @override
  int getIntAttribute(BaseAdapterAttribute attr) {
    switch(attr) {
      case BlocSuRecordAdapterAttribute.firstLocalConfirmation :
        return BlocSuRecordUtil.localConfirmationTimestamp(_blocSuRecord);
      case BlocSuRecordAdapterAttribute.lastModification :
        return _blocSuRecord.modificationTime;
      default:
        throw SuRecordException(SuRecordExceptionCode.INVALID_ARGUMENT,explanation: "");
    }
  }

  @override
  String getStringAttribute(BaseAdapterAttribute attr) {
    switch(attr) {
      default:
        throw SuRecordException(SuRecordExceptionCode.INVALID_ARGUMENT,explanation: "");
    }
  }

  @override
  List<String> getStringListAttribute(BaseAdapterAttribute attr) {
    switch(attr) {
      case BlocSuRecordAdapterAttribute.tags :
        return _blocSuRecord.tags;
      case BlocSuRecordAdapterAttribute.refs :
        return _blocSuRecord.refs;
      default:
        throw SuRecordException(SuRecordExceptionCode.INVALID_ARGUMENT,explanation: "");
    }
  }

  @override
  List<Object> get props => [_blocSuRecord];
}

// --------------------------------------------------------------
