/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:surec_app/surecord/surecord_exception.dart';
import 'package:surec_app/surecord/surecord_meta.dart';
import 'package:surec_app/filter/filter.dart';
import 'package:surec_app/surecord/surecord_util.dart';

class SuRecordFileAdapterAttribute implements BaseAdapterAttribute {
  final _value;
  const SuRecordFileAdapterAttribute._internal(this._value);
  toString() => 'SuRecordFileAdapterAttribute.$_value';

  static const tags = const SuRecordFileAdapterAttribute._internal('tags');
  static const refs = const SuRecordFileAdapterAttribute._internal('refs');
  static const idhash = const SuRecordFileAdapterAttribute._internal('idhash');
  static const firstLocalConfirmation = const SuRecordFileAdapterAttribute._internal('firstLocalConfirmation');
  static const firstRemoteConfirmation = const SuRecordFileAdapterAttribute._internal('firstRemoteConfirmation');
  static const lastRemoteConfirmation = const SuRecordFileAdapterAttribute._internal('lastRemoteConfirmation');
  static const lastModification = const SuRecordFileAdapterAttribute._internal('lastModification');
}

extension SuRecordFileAdapterAttributeType on SuRecordFileAdapterAttribute {
  static const _typeMap = {
    SuRecordFileAdapterAttribute.tags : RecordAdapterType.stringList,
    SuRecordFileAdapterAttribute.refs : RecordAdapterType.stringList,
    SuRecordFileAdapterAttribute.idhash : RecordAdapterType.string,
    SuRecordFileAdapterAttribute.firstLocalConfirmation : RecordAdapterType.int,
    SuRecordFileAdapterAttribute.firstRemoteConfirmation : RecordAdapterType.int,
    SuRecordFileAdapterAttribute.lastRemoteConfirmation : RecordAdapterType.int,
    SuRecordFileAdapterAttribute.lastModification : RecordAdapterType.int
  };

  RecordAdapterType type() {
    return _typeMap[this];
  }
}

// --------------------------------------------------------------

class SuRecordFileAdapter extends BaseAdapter {

  SuRecordFile _suRecordFile;
  SuRecordFileAdapter(SuRecordFile  this._suRecordFile);

  double getDoubleAttribute(BaseAdapterAttribute attr) {
    switch(attr) {
      default:
        throw SuRecordException(SuRecordExceptionCode.INVALID_ARGUMENT,explanation: "");
    }
  }

  @override
  int getIntAttribute(BaseAdapterAttribute attr) {
    switch(attr) {
      case SuRecordFileAdapterAttribute.firstLocalConfirmation :
        return SuRecordUtil.localConfirmationTimestamp(_suRecordFile.suRecord);
      case SuRecordFileAdapterAttribute.firstRemoteConfirmation :
        return SuRecordUtil.firstRemoteConfirmationTimestamp(_suRecordFile.suRecord);
      case SuRecordFileAdapterAttribute.firstRemoteConfirmation :
        return SuRecordUtil.lastRemoteConfirmationTimestamp(_suRecordFile.suRecord);
      case SuRecordFileAdapterAttribute.lastModification :
        return _suRecordFile.suRecord.modificationTime;
      default:
        throw SuRecordException(SuRecordExceptionCode.INVALID_ARGUMENT,explanation: "");
    }
  }

  @override
  String getStringAttribute(BaseAdapterAttribute attr) {
    switch(attr) {
      case SuRecordFileAdapterAttribute.idhash :
        return SuRecordUtil.idHash_fromSuRecordFile(_suRecordFile);
      default:
        throw SuRecordException(SuRecordExceptionCode.INVALID_ARGUMENT,explanation: "");
    }
  }

  @override
  List<String> getStringListAttribute(BaseAdapterAttribute attr) {
    switch(attr) {
      case SuRecordFileAdapterAttribute.tags :
        return _suRecordFile.suRecord.tags;
      case SuRecordFileAdapterAttribute.refs :
        return _suRecordFile.suRecord.refs;
      default:
        throw SuRecordException(SuRecordExceptionCode.INVALID_ARGUMENT,explanation: "");
    }
  }

  @override
  List<Object> get props => [_suRecordFile];
}

// --------------------------------------------------------------
