/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:camera/camera.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:logging/logging.dart';
import 'package:surec_app/app.dart';
import 'package:surec_app/surecord/surecord_blocrepo.dart';
import 'package:surec_app/surecord/surecord_config.dart';
import 'package:surec_app/surecord/surecord_repo.dart';
import 'package:surec_app/surecord/surecord_util.dart';
import 'package:surec_app/system_config.dart';
import 'package:path/path.dart' as p;

import 'package:surec_app/cache/fs_audio_cache.dart';
import 'package:surec_app/cache/cache_holder.dart';
import 'package:surec_app/cache/fs_image_and_video_cache.dart';
import 'package:surec_app/cache/fs_note_cache.dart';

void main() async{
  Logger.root.level = Level.INFO;
  Logger.root.onRecord.listen((record) {
    print('${record.level.name}: ${record.time}: ${record.message}');
  });

  final log = Logger("main");

  WidgetsFlutterBinding.ensureInitialized();
  var suRecordFilesOnFilesystem = await SuRecordUtil.listSuRecordFiles();
  log.info('finished listSuRecordFiles()');

  SuRecordFilesRepo _suRecordFilesRepo = SuRecordFilesRepo();
  _suRecordFilesRepo.initializeSuRecordFiles(suRecordFilesOnFilesystem);
  SuRecordBlocRepo  _suRecordBlocRepo = SuRecordBlocRepo(_suRecordFilesRepo);
  await _suRecordBlocRepo.initialized;
  log.info('finished _suRecordBlocRepo.initialized');

  final suRecordPath = await LocalSuRecordFilesConfig.pathToSuRecordFiles;

  ScanImageAndVideoCacheFilesResult scanImageAndVideoCacheFilesResult;
  var imageAndVideoCachePath = p.join("$suRecordPath","imageandvideocache");
  var imageAndVideoCacheThumbnailSize = 192;
  FSImageAndVideoCache imageAndVideoCache = FSImageAndVideoCache(imageAndVideoCacheThumbnailSize, imageAndVideoCachePath, false);
  try {
    scanImageAndVideoCacheFilesResult = await imageAndVideoCache.scanCacheFiles();
    log.info("finished imageAndVideoCache.scanCacheFiles()");
  } catch (e, s) {
    log.info("cache may not be ready");
  }
  Set<String> thumbnailsLoadedIntoMemCache;
  if(scanImageAndVideoCacheFilesResult != null) {
    thumbnailsLoadedIntoMemCache = imageAndVideoCache.loadThumbnailsFromFsIntoMemCache(scanImageAndVideoCacheFilesResult.thumbnails);
    log.info("finished imageAndVideoCache.loadThumbnailsFromFsIntoMemCache()");
  }

  ScanNoteCacheFilesResult scanNoteCacheFilesResult;
  var noteCachePath = p.join("$suRecordPath","notecache");
  var textsnippetSize = 400;
  FSNoteCache noteCache = FSNoteCache(textsnippetSize, noteCachePath, false);
  try {
    scanNoteCacheFilesResult = await noteCache.scanCacheFiles();
    log.info("finished noteCache.scanCacheFiles()");
  } catch (e, s) {
    log.info("cache may not be ready");
  }
  Set<String> textsnippetsLoadedIntoMemCache;
  if(scanNoteCacheFilesResult != null) {
    textsnippetsLoadedIntoMemCache = noteCache.loadTextsnippetsFromFsIntoMemCache(scanNoteCacheFilesResult.textsnippets);
    log.info("finished imageAndVideoCache.loadThumbnailsFromFsIntoMemCache()");
  }

  ScanAudioCacheFilesResult scanAudioCacheFilesResult;
  var audioCachePath = p.join("$suRecordPath","audiocache");
  FSAudioCache audioCache = FSAudioCache(audioCachePath);
  try {
    scanAudioCacheFilesResult = await audioCache.scanCacheFiles();
    log.info("finished audioCache.scanCacheFiles()");
  } catch (e, s) {
    log.info("cache may not be ready");
  }

  CacheHolder cacheHolder = CacheHolder();
  cacheHolder.initializeImageAndVideoCache(imageAndVideoCache);
  cacheHolder.initializeNoteCache(noteCache);
  cacheHolder.initializeAudioCache(audioCache);


  try {
    SystemConfig().cameraDescriptions = await availableCameras();
    log.info("finished availableCameras()");
  } on CameraException catch (e) {
    log.severe(e.code , e.description);
  }

  SystemChrome.setEnabledSystemUIOverlays([SystemUiOverlay.bottom]).then((_) {
    runApp(App());
  });
}
