/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:equatable/equatable.dart';
import 'package:surec_app/surecord/surecord_enums.dart';


class BlocFingerprint extends Equatable {
  final Algo algo;
  final String value;
  const BlocFingerprint(this.algo, this.value);

  @override
  List<Object> get props => [algo, value];
}


class BlocFingerprints extends Equatable {
  final List<BlocFingerprint> fingerprints;
  const BlocFingerprints(this.fingerprints);

  @override
  List<Object> get props => [fingerprints];
}


class BlocVerification extends Equatable {
  final String uri;
  final int timestamp;
  final List<BlocFingerprint> fingerprints;
  final BlocConfirmation confirmation;

  const BlocVerification(this.uri, this.timestamp, this.fingerprints, this.confirmation);

  @override
  List<Object> get props => [uri, timestamp, fingerprints, confirmation];
}


class BlocSuRecord extends Equatable {
  final List<BlocVerification> verifications;
  final List<String> tags;
  final List<String> refs;
  final int modificationTime;
  final SuRecordType type;
  final String id;

  const BlocSuRecord(this.verifications, this.tags, this.refs, this.modificationTime, this.type, this.id);

  @override
  List<Object> get props => [verifications,tags, refs, modificationTime, type, id];
}


class BlocSuRecordFile extends Equatable {
  final BlocSuRecord suRecord;
  final String surecFilename;

  const BlocSuRecordFile(this.suRecord, this.surecFilename);

  @override
  List<Object> get props => [suRecord, surecFilename];
}


class BlocSuRecords extends Equatable {
  final List<BlocSuRecord> suRecords;
  final int modificationTime;

  const BlocSuRecords(this.suRecords, this.modificationTime);

  @override
  List<Object> get props => [suRecords, modificationTime];
}


class BlocSuRecordFiles extends Equatable {
  final List<BlocSuRecordFile> suRecordFiles;
  final int modificationTime;

  const BlocSuRecordFiles(this.suRecordFiles, this.modificationTime);

  @override
  List<Object> get props => [suRecordFiles, modificationTime];
}


class BlocConfirmation extends Equatable {
  final String value;
  final Algo algo;
  final int timestamp;

  const BlocConfirmation(this.value, this.algo, this.timestamp);

  @override
  List<Object> get props => [value, algo, timestamp];
}
