/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:logging/logging.dart';
import 'package:surec_app/surecord/surecord_blocmeta.dart';
import 'package:surec_app/surecord/surecord_config.dart';
import 'package:surec_app/surecord/surecord_exception.dart';

class BlocSuRecordUtil {
  static final log = Logger('BlocSuRecordUtil');

  static int localConfirmationTimestamp(BlocSuRecord blocSuRecord) {
    SuRecordVerificationConfig localSuRecordVerifierConfig = LocalSuRecordVerificationConfig();

    var first;
    for (var verification in blocSuRecord.verifications) {
      if (localSuRecordVerifierConfig.verifierURI.compareTo(verification.uri) == 0) {
        first = verification.timestamp;
      }
    }
    if (first == null) {
      final message = "localConfirmationTimestamp surecord has no local confirmation timestamp";
      log.severe("$message");
      throw SuRecordException(SuRecordExceptionCode.INVALID_ARGUMENT, explanation: message);
    } else {
      return first;
    }
  }

  static String generateCacheEntryName(BlocSuRecord blocSuRecord) {
    return localConfirmationTimestamp(blocSuRecord).toRadixString(16).toUpperCase();
  }

}