/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'dart:async';
import 'dart:io';
import 'dart:io' show Platform;
import 'package:path_provider/path_provider.dart' as pp;
import 'package:surec_app/surecord/surecord_enums.dart';

// -----------------------------------------------------------------------------------------------------

abstract class SuRecordVerificationConfig {
  String get verifierURI;
  List<Algo> get verifcationAlgos;
  Algo get idAlgo;
  Algo get confirmationAlgo;
}

class LocalSuRecordVerificationConfig implements SuRecordVerificationConfig {
  static final String _verifierURI = "local";
  static final List<Algo> _verifcationAlgos = [Algo.SHA3_512, Algo.SHA_384];
  static final Algo _idAlgo = Algo.SHA3_512;
  static final Algo _confirmationAlgo = Algo.SHA3_224;

  String get verifierURI => _verifierURI;
  List<Algo> get verifcationAlgos => _verifcationAlgos;
  Algo get idAlgo => _idAlgo;
  Algo get confirmationAlgo => _confirmationAlgo;

}

// -----------------------------------------------------------------------------------------------------

abstract class SuRecordFilesConfig {
  String get metadataFilename;
  String get suRecordPostfix;
  static Future<String> pathToSuRecordFiles;
}

class LocalSuRecordFilesConfig implements SuRecordFilesConfig {
  static const _meatadataFilename = "meta.json";
  static const String _suRecordPostfix = "surec";
  static String _pathToSuRecordFiles;

  @override
  static Future<String> get pathToSuRecordFiles async {
    if (_pathToSuRecordFiles == null) {
      Directory appDocDir = await pp.getApplicationDocumentsDirectory();
      String appDocPath = appDocDir.path;

      if (Platform.isAndroid) {
        int index = appDocPath.lastIndexOf("/app_flutter");
        if (index > 0) {
          appDocPath = appDocPath.substring(0, index);
        }
      }
      _pathToSuRecordFiles = appDocPath;
    }
    return Future.value(_pathToSuRecordFiles);
  }

  @override
  String get suRecordPostfix => _suRecordPostfix;

  @override
  String get metadataFilename => _meatadataFilename;
}

// -----------------------------------------------------------------------------------------------------
