/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

part of 'surecord_cubit.dart';

@immutable
abstract class SuRecordCubitState extends Equatable {

  const SuRecordCubitState();

  @override
  List<Object> get props => [];
}


class SuRecordInitialCubitState extends SuRecordCubitState {
  @override
  List<Object> get props => [];
}


class SuRecordWorkingCubitState extends SuRecordCubitState {
  final String _transaction;
  String get transaction => _transaction;

  const SuRecordWorkingCubitState([this._transaction]);

  @override
  List<Object> get props => [transaction];
}


class SuRecordSavedCubitState extends SuRecordCubitState {
  final String _id;
  String get id => _id;

  final List<BlocSuRecord> _blocSuRecords;
  List<BlocSuRecord> get blocSuRecords => _blocSuRecords;

  final String _transaction;
  String get transaction => _transaction;

  const SuRecordSavedCubitState(this._id, this._blocSuRecords, this._transaction);

  @override
  List<Object> get props => [id, blocSuRecords, transaction];
}


class SuRecordSavedMetaCubitState extends SuRecordCubitState {
  final String _id;
  String get id => _id;

  final List<BlocSuRecord> _blocSuRecords;
  List<BlocSuRecord> get blocSuRecords => _blocSuRecords;

  final String _transaction;
  String get transaction => _transaction;

  const SuRecordSavedMetaCubitState(this._id, this._blocSuRecords, [String this._transaction=""]);

  @override
  List<Object> get props => [id, blocSuRecords, transaction];
}


class SuRecordFindByFilterCubitState extends SuRecordCubitState {
  final Filter _filter;
  Filter get filter => _filter;

  final List<BlocSuRecord> _blocSuRecords;
  List<BlocSuRecord> get blocSuRecords => _blocSuRecords;

  final String _transaction;
  String get transaction => _transaction;


  const SuRecordFindByFilterCubitState(this._filter, this._blocSuRecords, [String this._transaction=""]);

  @override
  List<Object> get props => [filter, blocSuRecords, transaction];
}


class SuRecordFindByIDCubitState extends SuRecordCubitState {
  final bool _found;
  bool get found => _found;

  final String _id;
  String get id => _id;

  final BlocSuRecord _blocSuRecord;
  BlocSuRecord get blocSuRecord => _blocSuRecord;

  final String _transaction;
  String get transaction => _transaction;

  const SuRecordFindByIDCubitState(this._found, this._id, this._blocSuRecord, [String this._transaction=""]);

  @override
  List<Object> get props => [found, id, blocSuRecord, transaction];
}


class SuRecordDeletedCubitState extends SuRecordCubitState {
  final bool _deleted;
  bool get deleted => _deleted;

  final String _id;
  String get id => _id;

  final List<BlocSuRecord> _blocSuRecords;
  List<BlocSuRecord> get blocSuRecords => _blocSuRecords;

  final String _transaction;
  String get transaction => _transaction;

  const SuRecordDeletedCubitState(this._deleted, this._id, this._blocSuRecords, [String this._transaction=""]);

  @override
  List<Object> get props => [deleted, id, blocSuRecords, transaction];
}


class SuRecordExistsCubitState extends SuRecordCubitState {
  final bool _exists;
  bool get exists => _exists;

  final String _id;
  String get id => _id;

  final String _transaction;
  String get transaction => _transaction;

  const SuRecordExistsCubitState(this._exists, this._id, [String this._transaction=""]);

  @override
  List<Object> get props => [exists, id, transaction];
}


class SuRecordCountCubitState extends SuRecordCubitState {
  final int _count;
  int get count => _count;

  final Set<String> _tags;
  Set<String> get tags => _tags;

  final String _transaction;
  String get transaction => _transaction;

  const SuRecordCountCubitState(this._count, this._tags, [String this._transaction=""]);

  @override
  List<Object> get props => [count, tags, transaction];
}


class SuRecordFailureCubitState extends SuRecordCubitState {
  final SuRecordFailureCubitStateValue _value;
  SuRecordFailureCubitStateValue get value => _value;

  final String _transaction;
  String get transaction => _transaction;

  const SuRecordFailureCubitState(SuRecordFailureCubitStateValue this._value, [String this._transaction=""]);

  @override
  List<Object> get props => [value, transaction];
}


enum SuRecordFailureCubitStateValue {
  NETWORK,
  UNSPECIFIED,
}
