/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:surec_app/surecord/surecord_blocmeta.dart';
import 'package:surec_app/surecord/surecord_meta.dart';
import 'package:surec_app/surecord/surecord_util.dart';


class SuRecordTranslate {

  static BlocFingerprint toBlocFingerprint(Fingerprint fingerprint) {
    return BlocFingerprint(fingerprint.algo, fingerprint.value);
  }

  static List<BlocFingerprint> toBlocFingerprints(List<Fingerprint> fingerprints) {
    List<BlocFingerprint> blocFingerprints = List<BlocFingerprint>();
    for (var fingerprint in fingerprints) {
      blocFingerprints.add(toBlocFingerprint(fingerprint));
    }
    return List<BlocFingerprint>.unmodifiable(blocFingerprints);
  }

  static BlocVerification toBlocVerification(Verification verification) {
    return BlocVerification(
        verification.uri,
        verification.timestamp,
        toBlocFingerprints(verification.fingerprints),
        toBlocConfirmation(verification.confirmation));
  }

  static List<BlocVerification> toBlocVerifications(List<Verification> verifications) {
    List<BlocVerification> blocVerifications = List<BlocVerification>();
    for(var verification in verifications) {
      blocVerifications.add(toBlocVerification(verification));
    }
    return List<BlocVerification>.unmodifiable(blocVerifications);
  }

  static BlocConfirmation toBlocConfirmation(Confirmation confirmation) {
    return BlocConfirmation(confirmation.value, confirmation.algo, confirmation.timestamp);
  }

  static List<BlocConfirmation> toBlocConfirmations(List<Confirmation> confirmations) {
    List<BlocConfirmation> blocConfirmations = List<BlocConfirmation>();
    for(var confirmation in confirmations) {
      blocConfirmations.add(toBlocConfirmation(confirmation));
    }
    return List<BlocConfirmation>.unmodifiable(blocConfirmations);
  }

  static BlocSuRecord toBlocSuRecord(SuRecord suRecord) {

    return BlocSuRecord(toBlocVerifications(suRecord.verifications),
        List<String>.unmodifiable(suRecord.tags),
        List<String>.unmodifiable(suRecord.refs),
        suRecord.modificationTime,
        suRecord.type,
        SuRecordUtil.idHash_fromSuRecord(suRecord));
  }

  static List<BlocSuRecord> toBlocSuRecordsfromSuRecords(List<SuRecord> suRecords) {
    List<BlocSuRecord> blocSuRecords = List<BlocSuRecord>();
    for(var suRecord in suRecords) {
      blocSuRecords.add(toBlocSuRecord(suRecord));
    };
    return List<BlocSuRecord>.unmodifiable(blocSuRecords);
  }

  static List<BlocSuRecord> toBlocSuRecordsfromSuRecordFiles(List<SuRecordFile> suRecordFiles) {
    List<BlocSuRecord> blocSuRecords = List<BlocSuRecord>();
    for(var suRecordFile in suRecordFiles) {
      blocSuRecords.add(toBlocSuRecord(suRecordFile.suRecord));
    }
    return List<BlocSuRecord>.unmodifiable(blocSuRecords);
  }
}
