/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'dart:convert';

import 'dart:async';
import 'dart:collection';
import 'dart:developer' as dev;
import 'dart:io';

import 'package:http/http.dart' as http;

import 'package:flutter_test/flutter_test.dart';
import 'package:surec_app/surecord/surecord_enums.dart';
import 'package:surec_app/surecord/surecord_exception.dart';
import 'package:surec_app/surecord/surecord_meta.dart';
import 'package:surec_app/surecord/surecord_util.dart';
import 'package:flutter/services.dart';
import 'package:logging/logging.dart';

import 'package:archive/archive.dart';
import 'package:archive/archive_io.dart';
import 'package:convert/convert.dart';
import 'package:flutter/services.dart' show rootBundle;
import 'package:collection/collection.dart';
import 'package:path/path.dart' as p;
import 'package:path_provider/path_provider.dart' as pp;

import 'package:pointycastle/pointycastle.dart'; // see importing https://pub.dev/packages/pointycastle
import 'package:pointycastle/digests/sha3.dart'; // see importing https://pub.dev/packages/pointycastle


class SuRecordWebserviceUtil {

  static Future<Verification> postFingerprintsForConfirmation(SuRecord localSuRecord) async {
  String localSuRecordJsonString = jsonEncode(localSuRecord);
  Map<String,dynamic> localSuRecordJson = localSuRecord.toJson();
  Verification firstVerification = localSuRecord.verifications.first;
  List<Fingerprint> firstFingerprints = firstVerification.fingerprints;
  Fingerprints wrappedFirstFingerprints = Fingerprints(firstFingerprints);
  var firstFingerprintsJson = jsonEncode(firstFingerprints);
  var wrappedFirstFingerprintsJson = jsonEncode(wrappedFirstFingerprints);


  var baseurl = "https://surec.app/api/v1";
  var confirmurl = baseurl + "/confirm";
  final response = await http.post(
      Uri.parse(confirmurl),
      headers: {
      HttpHeaders.contentTypeHeader: 'application/json'
      },
      body: wrappedFirstFingerprintsJson
  );
  if (response.statusCode == 200) {
    print(response);
    Confirmation confirmation =  Confirmation.fromJson(jsonDecode(response.body));
    Verification verification = Verification(baseurl, confirmation.timestamp, firstFingerprints, confirmation);
    return Future.value(verification);
  } else {
    throw SuRecordException(SuRecordExceptionCode.ERROR, explanation: "did not get confirmation");
  }
}
}