/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:flutter/material.dart';
import 'package:surec_app/ui/views/help/help_id_config.dart';
import 'package:surec_app/generated/l10n.dart';

class ExtendedBottomNavigationBarItem {
  final Widget view;
  final IconData icon;
  final String label;
  final HelpId helpId;

  const ExtendedBottomNavigationBarItem({ @required Widget view, @required IconData icon, @required String title, @required HelpId helpId})
      : this.view = view,
        this.icon = icon,
        this.label = title,
        this.helpId = helpId;

  ExtendedBottomNavigationBarItem.photoCapture(BuildContext context, this.view)
      : icon = Icons.camera,
        label = S.of(context).extendedBottomNavigationBarItemTitle_photoCapture,
        helpId = HelpId.photoCapture;

  ExtendedBottomNavigationBarItem.videoCapture(BuildContext context, this.view)
      : icon = Icons.video_call,
        label = S.of(context).extendedBottomNavigationBarItemTitle_videoCapture,
        helpId = HelpId.videoCapture;

  ExtendedBottomNavigationBarItem.audioCapture(BuildContext context, this.view)
      : icon = Icons.mic,
        label = S.of(context).extendedBottomNavigationBarItemTitle_audioCapture,
        helpId = HelpId.audioCapture;

  ExtendedBottomNavigationBarItem.noteCapture(BuildContext context, this.view)
      : icon = Icons.edit,
        label = S.of(context).extendedBottomNavigationBarItemTitle_noteCapture,
        helpId = HelpId.noteCapture;

  ExtendedBottomNavigationBarItem.listMain(BuildContext context, this.view)
      : icon = Icons.home,
        label = S.of(context).extendedBottomNavigationBarItemTitle_listMain,
        helpId = HelpId.listMain;

  ExtendedBottomNavigationBarItem.listExport(BuildContext context, this.view)
      : icon = Icons.list,
        label = S.of(context).extendedBottomNavigationBarItemTitle_listExport,
        helpId = HelpId.listExport;

  ExtendedBottomNavigationBarItem.detailTag(BuildContext context, this.view)
      : icon = Icons.edit,
        label = S.of(context).extendedBottomNavigationBarItemTitle_detailTag,
        helpId = HelpId.detailTag;

  ExtendedBottomNavigationBarItem.detailData(BuildContext context, this.view)
      : icon = Icons.adjust,
        label = S.of(context).extendedBottomNavigationBarItemTitle_detailData,
        helpId = HelpId.detailData;

  ExtendedBottomNavigationBarItem.help(BuildContext context, this.view)
      : icon = Icons.help,
        label = S.of(context).extendedBottomNavigationBarItemTitle_help,
        helpId = HelpId.invalid;

  BottomNavigationBarItem asBottomNavigationBarItem() {
    return BottomNavigationBarItem(icon: Icon(icon), label: label);
  }
}
