/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:flutter/material.dart';
import 'package:surec_app/ui/configuration/bottomnavbar_configuration.dart';
import 'package:surec_app/ui/views/help/help_id_config.dart';
import 'package:surec_app/ui/menu/extended_bottomnavbar_item.dart';
import 'package:surec_app/ui/routes/route_util.dart';
import 'package:surec_app/ui/views/help/help_view.dart';
import 'package:surec_app/ui/views/audio_view.dart';
import 'package:surec_app/ui/widgets/app_bar_util.dart';

class AudioRoute extends StatefulWidget {
  @override
  _AudioRouteState createState() => _AudioRouteState();
}

class _AudioRouteState extends State<AudioRoute> {

  int _currentIndex = 0;

  @override
  void initState(){
    super.initState();
  }

  void _onItemTapped(int index) {
    setState(() {
      _currentIndex = index;
    });
  }

  Widget build(BuildContext context) {

    var _extendedBottomNavigationBarItems = [
      ExtendedBottomNavigationBarItem.audioCapture(
          context,
          AudioView(
            onCaptureDone: (suRecord) => RouteUtil.routeToDetail(context, suRecord.id),
            onCaptureError: (error) => RouteUtil.popRoute(context),
          )),
      ExtendedBottomNavigationBarItem.help(context, HelpView(helpId: HelpId.invalid))
    ];

    List<BottomNavigationBarItem> bottomNavigationBarItems =
    BottomNavigationBarUtil.getBottomNavigationBarItems(_extendedBottomNavigationBarItems);

    List<Widget> bottomNavigationBarWidgets =
    BottomNavigationBarUtil.getBottomNavigationBarWidgets(_extendedBottomNavigationBarItems);

    var bottomNavigationBar = BottomNavigationBarUtil.buildThemedBottomNavigationBar(
      context: context, 
      onTap: (index) => _onItemTapped(index),
      currentIndex: _currentIndex, 
      items: bottomNavigationBarItems,      
    );

    return Scaffold(
        appBar: AppBarUtil.buildCancelAppBarWithPref(
            context,
            _extendedBottomNavigationBarItems[_currentIndex].label),
        body: IndexedStack(
          index: _currentIndex,
          children: bottomNavigationBarWidgets,
        ),
        bottomNavigationBar: bottomNavigationBar,
        backgroundColor: Theme.of(context).colorScheme.background,
    );
  }
}
