/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:flutter/material.dart';
import 'package:surec_app/ui/configuration/bottomnavbar_configuration.dart';
import 'package:surec_app/ui/views/help/help_id_config.dart';
import 'package:surec_app/ui/menu/extended_bottomnavbar_item.dart';
import 'package:surec_app/ui/routes/route_util.dart';
import 'package:surec_app/ui/views/detail/detail_capture_view.dart';
import 'package:surec_app/ui/views/help/help_view.dart';
import 'package:surec_app/ui/views/detail/detail_tag_view.dart';
import 'package:surec_app/ui/widgets/app_bar_util.dart';

class DetailRoute extends StatefulWidget {

  final String _suRecordId;
  final int _tabIdx;

  DetailRoute(this._suRecordId, this._tabIdx)
    : assert(_tabIdx >= 0);

  @override
  _DetailRouteState createState() => _DetailRouteState();
}

class _DetailRouteState extends State<DetailRoute> {

  int _currentIndex = 0;
  int _lastIndex = 0;

  @override
  void initState(){
    super.initState();
    _currentIndex = widget._tabIdx;
  }

  void _onItemTapped(int index) {
    setState(() {
      _lastIndex = _currentIndex;
      _currentIndex = index;
    });
  }

  Widget build(BuildContext context){
    var extendedBottomNavigationBarItem = _buildExtendedBottomNavigationBarItems();
    assert(_currentIndex < extendedBottomNavigationBarItem.length);
    
    var bottomNavigationBarItems  = BottomNavigationBarUtil.getBottomNavigationBarItems(extendedBottomNavigationBarItem);
    var _bottomNavigationBarWidgets = BottomNavigationBarUtil.getBottomNavigationBarWidgets(extendedBottomNavigationBarItem);

    var bottomNavigationBar = BottomNavigationBarUtil.buildThemedBottomNavigationBar(
      context: context, 
      onTap: (index) => _onItemTapped(index),
      currentIndex: _currentIndex, 
      items: bottomNavigationBarItems,      
    );

    return Scaffold(
        appBar: AppBarUtil.buildCancelAppBarWithPref(
            context,
            extendedBottomNavigationBarItem[_currentIndex].label),
        body: IndexedStack(
          index: _currentIndex,
          children: _bottomNavigationBarWidgets,
        ),
        bottomNavigationBar: bottomNavigationBar,
        backgroundColor: Theme.of(context).colorScheme.background,
    );

  }

  List<ExtendedBottomNavigationBarItem> _buildExtendedBottomNavigationBarItems(){
    
    var detailCaptureExtendedBottomNavigationBarItem = ExtendedBottomNavigationBarItem.detailData(
      context,
      DetailCaptureView(
        recordId: widget._suRecordId,
        onDeletedRecordDetailCapture: () => RouteUtil.popRoute(context),
      )
    );

    var detailTagExtendedBottomNavigationBarItem = ExtendedBottomNavigationBarItem.detailTag(
      context,
      DetailTagView(
        recordId: widget._suRecordId,
        onDoneDetailTag: () => RouteUtil.popRoute(context),
        onErrorDetailTag: () => RouteUtil.popRoute(context),
      )
    );

    var validHelpIds = [
      detailCaptureExtendedBottomNavigationBarItem.helpId,
      detailTagExtendedBottomNavigationBarItem.helpId,
    ];

    var helpId = _lastIndex < validHelpIds.length 
      ? validHelpIds[_lastIndex]
      : HelpId.invalid;

    var extendedBottomNavigationBarItems = [
      detailCaptureExtendedBottomNavigationBarItem,
      detailTagExtendedBottomNavigationBarItem,
      ExtendedBottomNavigationBarItem.help(
        context,
        HelpView(helpId: helpId), 
      )     
    ];

    return extendedBottomNavigationBarItems;
  }
}