/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:flutter/material.dart';
import 'package:surec_app/ui/routes/audio_route.dart';
import 'package:surec_app/ui/routes/detail_route.dart';
import 'package:surec_app/ui/routes/note_route.dart';
import 'package:surec_app/ui/routes/photo_route.dart';
import 'package:surec_app/ui/routes/prefs_route.dart';
import 'package:surec_app/ui/routes/start_route.dart';
import 'package:surec_app/ui/routes/video_route.dart';


enum DetailRouteTab{
  DETAIL_CAPTURE_VIEW,
  DETAIL_TAG_VIEW
}

class DetailArguments{
  final String suRecordId;
  final DetailRouteTab tab;

  DetailArguments(this.suRecordId, this.tab);
}

class RouteUtil{
  static const START = '/';
  static const PREFS = '/prefs';
  static const NOTE = '/note';
  static const VIDEO = '/video';
  static const PHOTO = '/photo';
  static const AUDIO = '/audio';
  static const DETAIL = '/detail';

  static MaterialPageRoute onGenerateRoute(RouteSettings settings){
    var route = settings.name;

    switch(route){
      case START:
        return MaterialPageRoute(builder: (context) => StartRoute());
      case PREFS:
        return MaterialPageRoute(builder: (context) => PrefsRoute());
      case NOTE:
        return MaterialPageRoute(builder: (context) => NoteRoute());
      case VIDEO:
        return MaterialPageRoute(builder: (context) => VideoRoute());
      case PHOTO:
        return MaterialPageRoute(builder: (context) => PhotoRoute());
      case AUDIO:
        return MaterialPageRoute(builder: (context) => AudioRoute());
      case DETAIL:
        assert(settings.arguments is DetailArguments);
        final DetailArguments args = settings.arguments;

        return MaterialPageRoute(builder: (context) => DetailRoute(args.suRecordId, args.tab.index));
      default:
        return MaterialPageRoute(builder: (context) => StartRoute());
    }
  }

  static void popRoute(BuildContext context){    
    Navigator.pop(context);
  }

  static void routeToDetail(BuildContext context, String suRecordId, {bool popAndPushed = true, DetailRouteTab tab = DetailRouteTab.DETAIL_TAG_VIEW}){
    var route = RouteUtil.DETAIL;
    var args = DetailArguments(suRecordId, tab);
    
    if(popAndPushed){
      Navigator.popAndPushNamed(
        context, 
        route, 
        arguments: args);
    }
    else{
      Navigator.pushNamed(
        context, 
        route, 
        arguments: args);
    }
  }

  static void routeToPref(BuildContext context){
    Navigator.pushNamed(context, RouteUtil.PREFS);
  }

  static void routeToNote(BuildContext context){
    _routeToRecordCapture(context, RouteUtil.NOTE);
  }

  static void routeToPhoto(BuildContext context){
    _routeToRecordCapture(context, RouteUtil.PHOTO);
  }
   
  static void routeToAudio(BuildContext context){
    _routeToRecordCapture(context, RouteUtil.AUDIO);
  }

  static void routeToVideo(BuildContext context){
    _routeToRecordCapture(context, RouteUtil.VIDEO);
  }

  static void _routeToRecordCapture(BuildContext context, String route){
    Navigator.pushNamed(context, route);
  }

}