/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:fab_circular_menu/fab_circular_menu.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:logging/logging.dart';

import 'package:surec_app/ui/views/help/help_id_config.dart';
import 'package:surec_app/ui/configuration/bottomnavbar_configuration.dart';
import 'package:surec_app/ui/layout_config.dart';
import 'package:surec_app/ui/menu/extended_bottomnavbar_item.dart';
import 'package:surec_app/ui/routes/route_util.dart';
import 'package:surec_app/ui/menu/fab_menu_item.dart';
import 'package:surec_app/ui/views/record_list/record_export_list_cubit.dart';
import 'package:surec_app/ui/views/record_list/record_export_list_view.dart';
import 'package:surec_app/ui/views/record_list/record_list_view.dart';
import 'package:surec_app/ui/views/help/help_view.dart';
import 'package:surec_app/ui/widgets/app_bar_util.dart';

class StartRoute extends StatefulWidget {
  @override
  _StartRouteState createState() => _StartRouteState();
}

class _StartRouteState extends State<StartRoute> {
  static final log = Logger('_StartRouteState');

  List<Widget> _fabMenuItems;

  int _currentIndex = 0;
  int _lastIndex = 0;

  void _onItemTapped(int index) {
    setState(() {
      _lastIndex = _currentIndex;
      _currentIndex = index;
    });
  }

  Widget build(BuildContext context) {

    _fabMenuItems = _buildFabItems([
      FabMenuItem(
          route: () => RouteUtil.routeToNote(context),
          title: "Note",
          icon: LayoutConfig.noteCaptureRecordIcon),
      FabMenuItem(
          route: () => RouteUtil.routeToPhoto(context),
          title: "Camera",
          icon: LayoutConfig.photoCaptureRecordIcon),
      FabMenuItem(
          route: () => RouteUtil.routeToAudio(context),
          title: "Audio",
          icon: LayoutConfig.audioCaptureRecordIcon),
      FabMenuItem(
          route: () => RouteUtil.routeToVideo(context),
          title: "Video",
          icon: LayoutConfig.videoCaptureRecordIcon),
    ]);

    var extendedBottomNavigationBarItem =
        _buildExtendedBottomNavigationBarItems();
    var bottomNavigationBarItems =
        BottomNavigationBarUtil.getBottomNavigationBarItems(
            extendedBottomNavigationBarItem);
    var bottomNavigationBarWidgets =
        BottomNavigationBarUtil.getBottomNavigationBarWidgets(
            extendedBottomNavigationBarItem);

    var bottomNavigationBar = BottomNavigationBarUtil.buildThemedBottomNavigationBar(
      context: context, 
      onTap: (index) => _onItemTapped(index),
      currentIndex: _currentIndex, 
      items: bottomNavigationBarItems,    
    );

    var ringDiameter = MediaQuery.of(context).size.width * 0.75;
    var fabItemIconColor = Theme.of(context).colorScheme.surface;
    return Scaffold(
        backgroundColor: Theme.of(context).colorScheme.background,
        extendBody: false,
        appBar: AppBarUtil.buildAppBarWithLogoAndPref(context, "surec"),
        body: IndexedStack(
            index: _currentIndex,
            children: bottomNavigationBarWidgets,
          ),
        floatingActionButton: FabCircularMenu(          
            fabColor: Theme.of(context).colorScheme.primary,
            ringColor: Theme.of(context).colorScheme.primaryVariant,            
            animationDuration: const Duration(milliseconds: 400),
            fabOpenIcon: Icon(
              Icons.add, 
              color: fabItemIconColor,
            ),
            fabCloseIcon: Icon(
              Icons.close, 
              color: fabItemIconColor,
            ),
            ringDiameter: ringDiameter,
            ringWidth: ringDiameter * 0.3,
            children: _fabMenuItems),
        bottomNavigationBar: bottomNavigationBar);
  }

  List<Widget> _buildFabItems(List<FabMenuItem> items) {
    return items.map((item) {
      return IconButton(
        icon: Icon(
          item.icon, 
        ),
        onPressed: () => item.route(),
      );
    }).toList();
  }

  List<ExtendedBottomNavigationBarItem>
      _buildExtendedBottomNavigationBarItems() {
    var mainListExtendedBottomNavigationBarItem =
        ExtendedBottomNavigationBarItem.listMain(context, RecordListView(BlocProvider.of<RecordExportListCubit>(context)));

    var exportListExtendedBottomNavigationBarItem =
        ExtendedBottomNavigationBarItem.listExport(
            context, RecordExportListView());

    var validHelpIds = [
      mainListExtendedBottomNavigationBarItem.helpId,
      exportListExtendedBottomNavigationBarItem.helpId,
    ];

    var helpId = _lastIndex < validHelpIds.length
        ? validHelpIds[_lastIndex]
        : HelpId.invalid;

    var extendedBottomNavigationBarItems = [
      mainListExtendedBottomNavigationBarItem,
      exportListExtendedBottomNavigationBarItem,
      ExtendedBottomNavigationBarItem.help(
        context,
        HelpView(helpId: helpId),
      )
    ];

    return extendedBottomNavigationBarItems;
  }
}
