/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'dart:async';

import 'package:bloc/bloc.dart';
import 'package:equatable/equatable.dart';
import 'package:surec_app/surecord/surecord_blocmeta.dart';
import 'package:surec_app/surecord/surecord_cubit.dart';

part 'detail_capture_state.dart';

class DetailCaptureCubit extends Cubit<DetailCaptureState> {
   
  final String _transactionPrefix = "detail_capture_transaction_";
  
  final SuRecordCubit _suRecordCubit;
  
  StreamSubscription _subscription;

  DetailCaptureCubit(this._suRecordCubit, String recordId) 
  : super(InitialDetailCaptureState(recordId)){
    _subscription = _suRecordCubit.listen((suRecordState) {
      if(state is !LoadingDetailCaptureState){
        return;
      }
      var currentState = state as LoadingDetailCaptureState;

      if( suRecordState is SuRecordFindByIDCubitState
        && currentState.transaction == suRecordState.transaction){
        emit(RecordLoadedDetailCaptureState(suRecordState.blocSuRecord));
      }
      else if(suRecordState is SuRecordDeletedCubitState
        && currentState.recordId == suRecordState.id){
        emit(RecordDeletedDetailCaptureState());
      }
      else if(suRecordState is SuRecordFailureCubitState
        && currentState.transaction == suRecordState.transaction){
        emit(FailureDetailCaptureState());
      }
    });
  }

  void findRecord(){
    assert(state is InitialDetailCaptureState);

    var id = (state as InitialDetailCaptureState).recordId;
    var transaction = createTransaction();
    
    emit(LoadingDetailCaptureState(transaction));
    _suRecordCubit.findById(id, transaction);
  }

  void deleteRecord(){
    assert(state is RecordLoadedDetailCaptureState);

    var id = (state as RecordLoadedDetailCaptureState).blocSuRecord.id;
    var transaction = createTransaction();
    
    emit(LoadingDetailCaptureState(transaction, id));
    _suRecordCubit.delete(id, transaction);
  }
  
  void addRecordToExport(){
    assert(state is RecordLoadedDetailCaptureState);

    var id = (state as RecordLoadedDetailCaptureState).blocSuRecord.id;
    // not implemented
  }

  String createTransaction(){
    return "$_transactionPrefix ${DateTime.now().millisecondsSinceEpoch.toString()}";
  }

  @override
  Future<void> close() {
    if (_subscription != null) {
      _subscription.cancel();
    }
    super.close();
  }
}
