/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:surec_app/surecord/surecord_blocmeta.dart';
import 'package:surec_app/surecord/surecord_cubit.dart';
import 'package:surec_app/ui/views/detail/detail_capture_cubit.dart';
import 'package:surec_app/ui/views/record_data_presentation/record_data_presentation_util.dart';

import 'package:surec_app/ui/widgets/icon_text_button.dart';
import 'package:surec_app/generated/l10n.dart';

typedef OnDeletedRecordDetailCapture = void Function();

class DetailCaptureView extends StatefulWidget {
  final String _recordId;

  final OnDeletedRecordDetailCapture _onDeletedRecordDetailCapture;

  DetailCaptureView(
      {@required String recordId,
      OnDeletedRecordDetailCapture onDeletedRecordDetailCapture})
      : this._recordId = recordId,
        this._onDeletedRecordDetailCapture =
            onDeletedRecordDetailCapture ?? null;

  @override
  _DetailCaptureViewState createState() => _DetailCaptureViewState();
}

class _DetailCaptureViewState extends State<DetailCaptureView> {

  Future<String> _blocSuRecordDataAsFutureString;

  @override
  Widget build(BuildContext context) {
    var suRecordCubit = BlocProvider.of<SuRecordCubit>(context);

    return BlocProvider<DetailCaptureCubit>(
      create: (context) =>
          DetailCaptureCubit(suRecordCubit, widget._recordId)..findRecord(),
      child: BlocConsumer<DetailCaptureCubit, DetailCaptureState>(
          listener: (context, detailCaptureState) {
        if (detailCaptureState is RecordLoadedDetailCaptureState) {
          _blocSuRecordDataAsFutureString = RecordDataPresentationUtil.loadBlocSuRecordDataForNormalView(
              detailCaptureState.blocSuRecord);
        }
      }, builder: (context, detailCaptureState) {
        if (detailCaptureState is RecordLoadedDetailCaptureState) {
          return _buildPresentation(detailCaptureState.blocSuRecord);          
        } else {
          return Container(child: Text(S.of(context).loadingProgressDefaultMessage));
        }
      }),
    );
  }

  Widget _buildAction() {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceEvenly,
      children: [
        IconTextButton(
            icon: Icons.delete_forever,
            label: S.of(context).detailCaptureViewDeleteIconButtonLabel,
            onPressed: () => widget._onDeletedRecordDetailCapture()),
        IconTextButton(
          icon: Icons.add,
          label: S.of(context).detailCaptureViewAddToExortIconButtonLabel,
          onPressed: () => null,
        )
      ],
    );
  }

  Widget _buildPresentation(BlocSuRecord blocSuRecord){
    return FutureBuilder(
        initialData: null,
        future: _blocSuRecordDataAsFutureString,
        builder: (context, snapshot) {
          return RecordDataPresentationUtil.buildBlocSuRecordPresentation(snapshot.data, blocSuRecord, false);
        });
  }
}
