/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

part of 'detail_tag_cubit.dart';

abstract class DetailTagState extends Equatable {
  DetailTagState();

  @override
  List<Object> get props => [];
}

class InitialDetailTagState extends DetailTagState{
  final String recordId;

  InitialDetailTagState(this.recordId);

  @override
  List<Object> get props => [recordId];
}

class FindAllAvailableTagsDetailTagState extends DetailTagState{
  final String recordId;
  final List<String> recordTags;

  FindAllAvailableTagsDetailTagState(this.recordId, this.recordTags);

  @override
  List<Object> get props => [recordId, recordTags];
}

class WorkingDetailTagState extends DetailTagState {
  final String recordId;
  final List<String> recordTags;
  final List<String> availableTags;  
  final String transaction;

  WorkingDetailTagState(this.recordId, this.transaction, {List<String> recordTags, List<String> availableTags})
    : this.recordTags = recordTags?? const [], 
      this.availableTags = availableTags?? const [];

  WorkingDetailTagState.fromEditState(EditDetailTagState state, this.transaction, {List<String> recordTags, List<String> availableTags})
    : this.recordId = state.recordId,
      this.recordTags = recordTags?? state.recordTagItems.map((item) => item.name).toList(), 
      this.availableTags = availableTags?? state.availableTagItems.map((item) => item.name).toList();

  @override
  List<Object> get props => [recordId, recordTags, availableTags, transaction];
}

class EditDetailTagState extends DetailTagState { 
  final String recordId; 
  final List<TagItem> recordTagItems;
  final List<TagItem> availableTagItems;

  EditDetailTagState(this.recordId, this.recordTagItems, this.availableTagItems);
    
  @override
  List<Object> get props => [recordId, recordTagItems, availableTagItems];
}

class DoneDetailTagState extends DetailTagState {  
  DoneDetailTagState();
}

class FailureTagState extends DetailTagState {  
  FailureTagState();
}