/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:surec_app/surecord/surecord_enums.dart';

class ReadOnlyTags{  
  static const READ_ONLY_PREFIX = ' ';
  
  static List<String> _noteTags = [
    "${READ_ONLY_PREFIX}note",
  ];

  static List<String> _audioTags = [
    "${READ_ONLY_PREFIX}audio",
  ];

  static List<String> _videoTags = [
    "${READ_ONLY_PREFIX}video",
  ];

  static List<String> _photoTags = [
    "${READ_ONLY_PREFIX}photo",
  ];
  
  static List<String> _notSupoortedTypeTags = [
    "${READ_ONLY_PREFIX}not supported type",
  ];

  static bool isReadOnly(String tag){
    return tag.startsWith(ReadOnlyTags.READ_ONLY_PREFIX);
  }

  static bool isNotReadOnly(String tag){
    return !tag.startsWith(ReadOnlyTags.READ_ONLY_PREFIX);
  }

  static String getTagWithoutPrefix(String tag){
    return tag.substring(READ_ONLY_PREFIX.length);
  }

  static List<String> getReadOnlyTagsOfType(SuRecordType type){
    List<String> tags = [];
    switch(type) {
      case SuRecordType.txt:
      case SuRecordType.md:
        tags.addAll(_noteTags);
        break;
      case SuRecordType.jpg:
      case SuRecordType.png:
        tags.addAll(_photoTags);
        break;
      case SuRecordType.mp3:
      case SuRecordType.wav:
      case SuRecordType.aac:
        tags.addAll(_audioTags);
        break;
      case SuRecordType.mp4:      
        tags.addAll(_videoTags);
        break;
      default:
        tags.addAll(_notSupoortedTypeTags);
    }

    return tags;
  }

}