/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:surec_app/bloc/visual_cubit.dart';
import 'package:surec_app/generated/l10n.dart';
import 'package:surec_app/ui/views/help/help_id_config.dart';
import 'package:flutter_markdown/flutter_markdown.dart';


class HelpView extends StatelessWidget {
  final HelpId _helpId;
  String helpContent;

  HelpView({@required helpId, Key key})
  : this._helpId = helpId,
    super(key: key) {}

  String contentForId(BuildContext context, HelpId helpId) {
    switch(helpId) {
      case HelpId.invalid : return S.of(context).helpId_invalid;
      case HelpId.listMain : return S.of(context).helpId_listMain;
      case HelpId.listExport : return S.of(context).helpId_listExport;
      case HelpId.noteCapture : return S.of(context).helpId_noteCapture;
      case HelpId.photoCapture : return S.of(context).helpId_photoCapture;
      case HelpId.videoCapture : return S.of(context).helpId_videoCapture;
      case HelpId.audioCapture : return S.of(context).helpId_audioCapture;
      case HelpId.detailData : return S.of(context).helpId_detailData;
      case HelpId.detailTag : return S.of(context).helpId_detailTag;
    }
  }

  @override
  Widget build(BuildContext context) {
    String content = contentForId(context, _helpId);

    return (BlocProvider.value(
        value: BlocProvider.of<VisualCubit>(context),
        child: Container(
            margin: const EdgeInsets.all(0.0),
            // width: MediaQuery.of(context).size.width,
            // height: MediaQuery.of(context).size.height / 3,
            child: Container(
                margin: const EdgeInsets.all(0.0),
                color: Colors.grey[200],      // TODO: style after visual cubit
                // width: -10 + MediaQuery.of(context).size.width,
                // height: -10 + MediaQuery.of(context).size.height / 3,
                child: Markdown(data: contentForId(context, _helpId)
            )
            )
    )
    )
    );
  }

}

