/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:flutter/material.dart';
import 'package:surec_app/generated/l10n.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:surec_app/bloc/visual_cubit.dart';
import 'package:logging/logging.dart';

class PrefsView extends StatelessWidget {
  final log = Logger('PrefsView');

  PrefsView({
    Key key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return (BlocProvider.value(
        value: BlocProvider.of<VisualCubit>(context),
        child:
        ListView(
          padding: EdgeInsets.zero,
          children: <Widget>[
            SwitchListTile(
              title: Text(S.of(context).prefViewDarkModeLabel),
              secondary: const Icon(Icons.lightbulb),
              value: context.read<VisualCubit>().state.mode == Mode.dark,
              onChanged: (value) {
                log.info("value coming in     Mode.dark == " + value.toString());
                log.info("context.bloc<VisualCubit>().state.mode: " + context.read<VisualCubit>().state.mode.toString());
                if (value) {
                  context.read<VisualCubit>().setModeDark();
                } else {
                  context.read<VisualCubit>().setModeLight();
                }
              },
            ),

            SwitchListTile(
              title: Text(S.of(context).prefViewIncreaseFontSizeLabel),
              secondary: const Icon(Icons.format_size),
              value: context.read<VisualCubit>().state.fontSize == FontSize.big,
              onChanged: (value) {
                log.info("value coming in :" + value.toString());
                log.info("context.bloc<VisualCubit>().state.fontSize: " + context.read<VisualCubit>().state.fontSize.toString());
                if (value) {
                  context.read<VisualCubit>().setFontSizeBig();
                } else {
                  context.read<VisualCubit>().setFontSizeStd();
                }
              },
            ),

            SwitchListTile(
              title: Text(S.of(context).prefViewIncreaseContrastLabel),
              secondary: const Icon(Icons.workspaces_filled),   // TODO: find better icon. .. .brightness_high ?
              value: context.read<VisualCubit>().state.contrast == Contrast.high,
              onChanged: (value) {
                log.info("value coming in :" + value.toString());
                log.info("context.bloc<VisualCubit>().state.contrast: " + context.read<VisualCubit>().state.contrast.toString());
                if (value) {
                  context.read<VisualCubit>().setContrastHigh();
                } else {
                  context.read<VisualCubit>().setContrastStd();
                }
              },
            ),
          ],
        ))
    );
  }
}
