/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:intl/intl.dart';

import 'package:flutter/material.dart';
import 'package:surec_app/surecord/surecord_blocmeta.dart';
import 'package:surec_app/ui/layout_config.dart';
import 'package:surec_app/ui/routes/route_util.dart';
import 'package:surec_app/ui/util/date_time_formatter_util.dart';
import 'package:surec_app/ui/views/record_list/expand_record_list_item.dart';
import 'package:surec_app/ui/views/record_list/record_export_list_cubit.dart';
import 'package:surec_app/ui/views/record_list/record_list_item.dart';

class RecordListBuilder extends StatefulWidget {

  final List<BlocSuRecord> _blocSuRecords;
  final Function(BlocSuRecord blocSuRecord) _onDeleteRecord;
  final bool _useDateRecordDivider;
  final bool _useRecordToExportListAction;

  RecordListBuilder({
    @required List<BlocSuRecord> blocSuRecords,
    Function(BlocSuRecord blocSuRecord) onDeleteRecord,
    // Function(String id) onToggleRecordToExportList,
    bool useDateRecordDivider=false,
    bool useRecordToExportListAction=false})
    : _blocSuRecords = blocSuRecords,
      _onDeleteRecord = onDeleteRecord?? null,
      _useDateRecordDivider = useDateRecordDivider,
      _useRecordToExportListAction = useRecordToExportListAction;
  
  @override
  _RecordListBuilderState createState() => _RecordListBuilderState();
}

class _RecordListBuilderState extends State<RecordListBuilder> {
  
  void Function(String id) _onTapRecordItem;

  @override
  void initState() {
    super.initState();

    _onTapRecordItem = (suRecordId) => RouteUtil.routeToDetail(
      context, 
      suRecordId, 
      popAndPushed: false,
      tab: DetailRouteTab.DETAIL_CAPTURE_VIEW);    
  }

  @override
  Widget build(BuildContext context) {
    return _buildRecordList(context, widget._blocSuRecords);
  }

  Widget _buildRecordList(BuildContext context, List<BlocSuRecord> records) {
    
    return Scrollbar(
      child: ListView.builder(
        padding: const EdgeInsets.all(LayoutConfig.simpleWidgetSpacing),
        itemCount: records.length,
        itemBuilder: (context, index) {
          var currentRecord = records[index];    
                
          var currentDate = DateTimeFormatterUtil.formatBlocSuRecordTimeStampToMonthYear(currentRecord);

          var dividerWithRecord = 
            () => _buildDividerAndRecord(
              blocSuRecord: records[index],
              context: context
            );
          
          if(widget._useDateRecordDivider){
            var dateHeaderWithRecord = 
              () => _buildDividerAndRecord(
                  blocSuRecord: currentRecord,
                  context: context,
                  hasDateHeader: true,
                  date: currentDate
              );      

            if (index != 0) {
              var lastDate = DateTimeFormatterUtil.formatBlocSuRecordTimeStampToMonthYear(records[index - 1]);                
              return currentDate == lastDate
                  ? dividerWithRecord()
                  : dateHeaderWithRecord();
            } else {
              return dateHeaderWithRecord();
            }
          }
          else{
            return dividerWithRecord();
          }
        },
      ),
    );
  }

  Widget _buildDividerAndRecord({
    @required BlocSuRecord blocSuRecord,    
    @required BuildContext context,
    bool hasDateHeader=false, String date, }){
    
    return Column(
      children: [
        hasDateHeader 
        ? Container(
            color: Theme.of(context).colorScheme.surface,
            padding: EdgeInsets.all(LayoutConfig.doubleWidgetSpacing),
            child: Center(
              child: Text(date, 
              textScaleFactor: 1.2,
                style: TextStyle(fontWeight: FontWeight.bold),),
            ),
          )
        : Divider(color: Theme.of(context).colorScheme.primaryVariant,),
          // RecordListItem(
             ExpandRecordListItem(
            key: ValueKey(blocSuRecord.id),
            blocSuRecord: blocSuRecord,
            onTapItem: (recordId) => _onTapRecordItem(recordId),
            onDeleteItem: widget._onDeleteRecord != null ? (blocSuRecord) => widget._onDeleteRecord(blocSuRecord) : null,
            useRecordToExportListAcion: widget._useRecordToExportListAction,
            recordExportListCubit: BlocProvider.of<RecordExportListCubit>(context),
          ),
      ],
    );
  }
}