/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'dart:async';

import 'package:bloc/bloc.dart';
import 'package:equatable/equatable.dart';
import 'package:surec_app/filter/blocsurecord_filter.dart';
import 'package:surec_app/filter/filter.dart';
import 'package:surec_app/surecord/surecord_blocmeta.dart';
import 'package:surec_app/surecord/surecord_cubit.dart';

part 'record_list_state.dart';

class RecordListCubit extends Cubit<RecordListState> {
  SuRecordCubit _suRecordCubit;
  StreamSubscription _subscription;
  List<FilterExpression> _filterExpressions = [];

  RecordListCubit(this._suRecordCubit) : super(RecordListState(blocSuRecords: [], filteredBlocSuRecords: [])) {
    _subscription = _suRecordCubit.listen((suRecordState) {
    
      bool updateFilteredBlocSuRecords = false;

      if (suRecordState is SuRecordInitialCubitState) {
        _suRecordCubit.findAll();
      } 
      else if (suRecordState is SuRecordSavedCubitState) {
        var blocSuRecords = suRecordState.blocSuRecords;
        updateFilteredBlocSuRecords = true;
         emit(RecordListState(blocSuRecords: blocSuRecords, filteredBlocSuRecords: blocSuRecords));
      }
      else if (suRecordState is SuRecordSavedMetaCubitState){
        var blocSuRecords = suRecordState.blocSuRecords;
        updateFilteredBlocSuRecords = true;
        emit(RecordListState(blocSuRecords: blocSuRecords, filteredBlocSuRecords: blocSuRecords));
      }
      else if (suRecordState is SuRecordFindByFilterCubitState){
        var blocSuRecords = suRecordState.blocSuRecords;        
        updateFilteredBlocSuRecords = true;
        emit(RecordListState(blocSuRecords: blocSuRecords, filteredBlocSuRecords: blocSuRecords));
      }
      else if (suRecordState is SuRecordDeletedCubitState){
        // emit(RecordListState.from(state, blocSuRecords: suRecordState.blocSuRecords));
      }
      else
      {
        // set old record list, when suRecord state is:
        // SuRecordWorkingCubitState
        // SuRecordFindByIDCubitState
        // SuRecordCountCubitState
        // SuRecordExistsCubitState               
        // emit(RecordListState.from(state));                         
      }

      if(state.blocSuRecords.isNotEmpty 
        && _filterExpressions.isNotEmpty
        && updateFilteredBlocSuRecords){
          filterBlocSuRecords(_filterExpressions);
      }
    });
  }

  void initialRecordList() {       
    _suRecordCubit.findAll();
  }

  void filterBlocSuRecords(List<FilterExpression> filterExpressions){    
    _filterExpressions = filterExpressions;
    var blocSuRecords = state.blocSuRecords;
    if(_filterExpressions.isNotEmpty){
      var matchingBlocSuRecords = blocSuRecords.where((record) {
        var adapter = BlocSuRecordAdapter(record);      
        for(var filter in _filterExpressions ){
          if(!filter.match(adapter)){
            return false;
          }
        }
        return true;
      }).toList();

      List<BlocSuRecord> filteredBlocSuRecordList = [];
      filteredBlocSuRecordList.addAll(matchingBlocSuRecords);
      emit(RecordListState.from(state, filteredBlocSuRecords: matchingBlocSuRecords));       
    }
    else{
      emit(RecordListState(blocSuRecords: blocSuRecords, filteredBlocSuRecords: blocSuRecords));
    }
  }

  void deleteBlocSuRecord(BlocSuRecord blocSuRecord){    
    List<BlocSuRecord> recordList = [];
    recordList.addAll(state.blocSuRecords);
    recordList.remove(blocSuRecord);

    List<BlocSuRecord> filteredBlocSuRecords = [];
    filteredBlocSuRecords.addAll(state.filteredBlocSuRecords);
    filteredBlocSuRecords.remove(blocSuRecord);    
    
    emit(RecordListState(blocSuRecords: recordList, filteredBlocSuRecords: filteredBlocSuRecords));

    _suRecordCubit.delete(blocSuRecord.id);    
  }

  @override
  Future<void> close() {
    if (_subscription != null) {
      _subscription.cancel();
    }
    super.close();
  }
}
