/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:flutter/material.dart';
import 'package:surec_app/ui/layout_config.dart';

class ActionButton extends StatelessWidget {
  final IconData _icon;
  final Function _onPressed;
  final String _label;

  ActionButton({IconData icon, Function onPressed, String label})
      : _icon = icon,
        _onPressed = onPressed,
        _label = label;

  @override
  Widget build(BuildContext context) {
    return FittedBox(
      fit: BoxFit.contain,
      alignment: Alignment.center,
      child: InputChip(
        onPressed: _onPressed,
        label: Row(
          mainAxisAlignment: MainAxisAlignment.spaceAround,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Padding(
              padding: const EdgeInsets.all(LayoutConfig.doubleWidgetSpacing),
              child: Text(_label),
            ),
            Icon(
              _icon,
              color: Theme.of(context).colorScheme.surface,
            )
          ],
        ),
        backgroundColor: Theme.of(context).colorScheme.primary,
        labelStyle: TextStyle(color: Theme.of(context).colorScheme.surface),
      ),
    );
  }
}
