/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:flutter/material.dart';
import 'package:surec_app/ui/layout_config.dart';
import 'package:surec_app/ui/routes/route_util.dart';

class AppBarUtil {
  static Widget buildCancelAppBarWithPref(BuildContext context, String title) {
    return _themedAppBar(context,
        title: title,
        leading: IconButton(
          icon: Icon(Icons.close),
          onPressed: () => RouteUtil.popRoute(context),
        ),
        actions: [_buildPrefAction(context)]);
  }

  static Widget buildCancelAppBar(BuildContext context, String title) {
    return _themedAppBar(
      context,
      title: title,
      leading: IconButton(
        icon: Icon(Icons.close),
        onPressed: () => RouteUtil.popRoute(context),
      ),
    );
  }

  static Widget buildAppBarWithLogoAndPref(BuildContext context, String title) {
    var textLogoColor = Theme.of(context).colorScheme.surface;
    var backgroundColor = Theme.of(context).colorScheme.secondary;
    return _themedAppBar(context,
        title: title,
        leading: CircleAvatar(    

          backgroundColor: backgroundColor,
          child: Text(
              "s",
              textScaleFactor: 3,
              style:
                  TextStyle(color: textLogoColor, fontWeight: FontWeight.bold),
            ),
        ),
        actions: [_buildPrefAction(context)]);
  }

  static Widget _themedAppBar(BuildContext context,
      {String title, Widget leading, List<Widget> actions = const []}) {
    return AppBar(
      backgroundColor: Theme.of(context).colorScheme.primary,
      leading: leading,
      title: Text(title),
      centerTitle: true,
      actions: actions,
    );
  }

  static Widget _buildPrefAction(BuildContext context) {
    return IconButton(
      icon: Icon(LayoutConfig.prefIcon),
      onPressed: () => RouteUtil.routeToPref(context),
    );
  }
}
