/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:flutter/material.dart';
import 'package:surec_app/filter/blocsurecord_filter.dart';
import 'package:surec_app/filter/filter.dart';
import 'package:surec_app/ui/util/date_time_formatter_util.dart';
import 'package:surec_app/generated/l10n.dart';
import 'package:surec_app/ui/widgets/filter_options/filter_option_cubit.dart';

class DateFilter extends StatefulWidget {
  final FilterOptionCubit _filterOptionCubit;
  DateFilter(this._filterOptionCubit);

  @override
  _DateFilterState createState() => _DateFilterState();
}

DateTime _firstDatePickerDateTime;
DateTime _fromSelectedFilterDate;
DateTime _toSelectedFilterDate;

class _DateFilterState extends State<DateFilter> {
  @override
  void initState() {
    super.initState();
    _firstDatePickerDateTime = DateTime(2020);
    _fromSelectedFilterDate = _firstDatePickerDateTime;
    _toSelectedFilterDate = DateTime.now();
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        // Text("Date"),
        _fromDateFilter(context),
        _toDateFilter(context)
      ],
    );
  }

  Widget _fromDateFilter(BuildContext context) {
    var currentDate = DateTime.now();
    return _dateFilter(
        label: S.of(context).dateFilterWidgetDateFromLabel,
        date: _dateTimeToDateFormatter(_fromSelectedFilterDate),
        onTapDateFilter: () {
          showDatePicker(
            context: context,
            initialDate: _fromSelectedFilterDate,
            firstDate: _firstDatePickerDateTime,
            lastDate: currentDate,
          ).then((selectedDate) {
            if (selectedDate != _fromSelectedFilterDate) {
              setState(() {
                _fromSelectedFilterDate = selectedDate;
                _updateFilterExpression();
              });
            }
          });
        });
  }

  Widget _toDateFilter(BuildContext context) {
    var currentDate = DateTime.now();
    return _dateFilter(
        label: S.of(context).dateFilterWidgetDateToLabel,
        date: _dateTimeToDateFormatter(_toSelectedFilterDate),
        onTapDateFilter: () {
          showDatePicker(
            context: context,
            initialDate: _toSelectedFilterDate ?? currentDate,
            firstDate: _firstDatePickerDateTime,
            lastDate: currentDate,
          ).then((selectedDate) {
            if (selectedDate != _toSelectedFilterDate) {
              setState(() {
                var today = DateTime.now();
                if (selectedDate.day == today.day &&
                    selectedDate.month == today.month &&
                    selectedDate.year == today.year) {
                  _toSelectedFilterDate = DateTime.now();
                } else {
                  _toSelectedFilterDate = selectedDate;
                }
                _updateFilterExpression();
              });
            }
          });
        });
  }

  void _updateFilterExpression() {
    FilterExpression greaterOrEqualFilter = AttributeValueIntIsGreaterOrEqual(
        BlocSuRecordAdapterAttribute.firstLocalConfirmation,
        _fromSelectedFilterDate.millisecondsSinceEpoch);
    FilterExpression lessOrEqualFilter = AttributeValueIntIsLessOrEqual(
        BlocSuRecordAdapterAttribute.firstLocalConfirmation,
        _toSelectedFilterDate.millisecondsSinceEpoch);

    var filter = AndExpression(greaterOrEqualFilter, lessOrEqualFilter);
    widget._filterOptionCubit
        .updateFilterExpressions(FilterOptionKey.DATE, filter);
  }

  Widget _dateFilter(
      {String label, String date, void Function() onTapDateFilter}) {
    return GestureDetector(
      onTap: () => onTapDateFilter(),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        children: [
          Text(label),
          Container(
            padding: EdgeInsets.all(8.0),
            child: Text(date),
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(5.0),
              border: Border.all(),
            ),
          ),
        ],
      ),
    );
  }

  String _dateTimeToDateFormatter(DateTime dateTime) {
    // return "${dateTime.toLocal()}".split(" ")[0];
    return DateTimeFormatterUtil.formatDateTimeToYearMonthDay(dateTime);
  }
}
