/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:surec_app/surecord/surecord_cubit.dart';
import 'package:surec_app/ui/widgets/filter_options/filter_option_cubit.dart';
import 'package:surec_app/ui/widgets/filter_options/tag_filter_cubit.dart';
import 'package:surec_app/generated/l10n.dart';

enum TagFilterMode{
  ADDITIONAL,
  SUBTRACTIONAL
}

class TagFilter extends StatefulWidget {
  final SuRecordCubit _suRecordCubit;
  final FilterOptionCubit _filterOptionCubit;
  final TagFilterMode _filterMode;

  TagFilter(this._suRecordCubit, this._filterOptionCubit,{TagFilterMode filterMode})
    : _filterMode = filterMode?? TagFilterMode.SUBTRACTIONAL;

  @override
  _TagFilterState createState() => _TagFilterState();
}

class _TagFilterState extends State<TagFilter> {
  Color _tagIsSelectedColor;
  Color _tagUnselectedColor;

  @override
  Widget build(BuildContext context) {
    _tagUnselectedColor = widget._filterMode == TagFilterMode.ADDITIONAL 
      ? Theme.of(context).colorScheme.background
      : Theme.of(context).colorScheme.primaryVariant;

    _tagIsSelectedColor = widget._filterMode == TagFilterMode.ADDITIONAL 
      ? Theme.of(context).colorScheme.primaryVariant
      : Theme.of(context).colorScheme.background;

    var filterWidgetHeight = MediaQuery.of(context).size.height * 0.15;

    return BlocProvider<TagFilterCubit>(
      create: (context) =>
          TagFilterCubit(widget._suRecordCubit, widget._filterOptionCubit)..findAllAvailableTags(),
      child: BlocBuilder<TagFilterCubit, TagFilterState>(
        builder: (context, tagFilterState) {
          if (tagFilterState is TagFilterUpdate) {
            var tagItems = List.generate(
                tagFilterState.availableTags.length,
                (index) => _buildTagItem(
                    tag: tagFilterState.availableTags[index],
                    isSelected: tagFilterState.selectedTags
                        .contains(tagFilterState.availableTags[index]),
                    onToggleTagSelection: (tag) =>
                        BlocProvider.of<TagFilterCubit>(context)
                            .toggleTagSelection(tag, widget._filterMode)));

            return SizedBox(
              height: filterWidgetHeight,
              child: Scrollbar(
                child: SingleChildScrollView(
                  child:
                      Wrap(spacing: 4.0, runSpacing: 4.0, children: tagItems),
                ),
              ),
            );
          } else {
            return Container(
              child: Text(S.of(context).tagFilterNoAvailableTagsMessage),
              alignment: Alignment.center,
            );
          }
        },
      ),
    );
  }

  Widget _buildTagItem(
      {String tag,
      bool isSelected,
      Function(String tag) onToggleTagSelection}) {
    return GestureDetector(
      onTap: () => onToggleTagSelection(tag),
      child: Chip(
        backgroundColor: isSelected ? _tagIsSelectedColor : _tagUnselectedColor,
        label: Text(tag),
      ),
    );
  }

}
