/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec_app - prototype fund round 8 release.

    surec_app is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec_app is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import 'dart:async';

import 'package:bloc/bloc.dart';
import 'package:equatable/equatable.dart';
import 'package:surec_app/filter/blocsurecord_filter.dart';
import 'package:surec_app/filter/filter.dart';
import 'package:surec_app/surecord/surecord_cubit.dart';
import 'package:surec_app/ui/widgets/filter_options/filter_option_cubit.dart';
import 'package:surec_app/ui/widgets/filter_options/tag_filter.dart';

part 'tag_filter_state.dart';

class TagFilterCubit extends Cubit<TagFilterState> {
  SuRecordCubit _suRecordCubit;
  FilterOptionCubit _filterOptionCubit;
  StreamSubscription _subscription;

  TagFilterCubit(this._suRecordCubit, this._filterOptionCubit) : super(TagFilterUpdate([],[])){
    _subscription = _suRecordCubit.listen((suRecordState) {
      if(suRecordState is SuRecordCountCubitState){
        emit(TagFilterUpdate.from(
          state, 
          availableTags: suRecordState.tags.toList()));
      }else if (suRecordState is SuRecordSavedCubitState){
        findAllAvailableTags();
      }
    });
  }

  void findAllAvailableTags(){    
    emit(TagFilterUpdate.from(state));
    _suRecordCubit.count();    
  }

  void toggleTagSelection(String tag, TagFilterMode filterMode){    
    assert(state is TagFilterUpdate);
    var currentState = state as TagFilterUpdate;

    List<String> selectedTags = [];
    selectedTags.addAll(currentState.selectedTags);
    if(selectedTags.contains(tag)){
      selectedTags.remove(tag);
    }
    else{
      selectedTags.add(tag);
    }

    emit(TagFilterUpdate.from(currentState, selectedTags: selectedTags));
    _updateFilterExpression(selectedTags, filterMode);
  }


  void _updateFilterExpression(List<String> tags, TagFilterMode filterMode) {
    FilterExpression filter;
    for (int i = 0; i < tags.length; i++) {
      if (i == 0) {        
        filter = filterMode == TagFilterMode.ADDITIONAL 
        ? AttributeValueStringListContainsExpression(BlocSuRecordAdapterAttribute.tags, tags[i])
        : AttributeValueStringListNotContainsExpression(BlocSuRecordAdapterAttribute.tags, tags[i]);
      } else {
        filter = filterMode == TagFilterMode.ADDITIONAL 
        ? AndExpression( filter, AttributeValueStringListContainsExpression(BlocSuRecordAdapterAttribute.tags, tags[i]))
        : AndExpression( filter, AttributeValueStringListNotContainsExpression(BlocSuRecordAdapterAttribute.tags, tags[i]));
      }
    }

    _filterOptionCubit.updateFilterExpressions(FilterOptionKey.TAGS, filter);
  }

  @override
  Future<void> close() {
    if (_subscription != null) {
      _subscription.cancel();
    }
    super.close();
  }
}
