/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec backend - prototype fund round 8 release.

    surec backend is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec backend is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

package eu.surec.backend.controller

import eu.surec.backend.repositories.ConfirmationRepository
import eu.surec.backend.util.ServiceStatus
import org.slf4j.LoggerFactory
import org.springframework.stereotype.Controller
import org.springframework.ui.Model
import org.springframework.ui.ModelMap
import org.springframework.ui.set
import org.springframework.web.bind.annotation.*
import org.springframework.beans.factory.annotation.Autowired
import java.text.SimpleDateFormat
import java.time.format.DateTimeFormatter
import java.util.*

@Controller
class HtmlController(@Autowired private val confirmationRepository: ConfirmationRepository) {
    private val log = LoggerFactory.getLogger(HtmlController::class.java)

    @GetMapping("/status")
    fun serviceStatusPage(model: Model): String {
        log.info("get/status", "");
        if (ServiceStatus().currentStatus) {
            model["status"] = "Service OK"
            return "servicestatuspage"
        } else {
            model["status"] = "Service not OK"
            return "servicestatuspage"
        }
    }

    @GetMapping("/confirmations")
    fun serviceStatusPage(modelMap: ModelMap): String {
        log.info("get/confirmations", "");
        try {
            var pattern = "yyyy-MM-dd HH:mm:ss.SSSSSSSS";
            pattern = "yyyy-MM-dd'T'HH:mm:ss.SSSZ"
            var formatter = DateTimeFormatter.ofPattern(pattern);
            var sdformatter = SimpleDateFormat(pattern);
            log.info("get data")
            var formattedConfirmations = mutableListOf<FormattedConfirmation>()
            var confirmations = confirmationRepository.findAll();
            for(confirmation in confirmations) {
                val date = Date(confirmation.timestamp)
                val formatted = sdformatter.format(date)
                var formattedConfirmation = FormattedConfirmation(
                    confirmation.algo.toString(),
                    confirmation.value.toString(),
                    formatted
                )
                formattedConfirmations.add(formattedConfirmation)
            }

            modelMap.addAttribute("confirmations", formattedConfirmations)
            return "confirmations"
        } catch (e: ExceptionInInitializerError) {
            log.error("get index", e)
        }
        return "error"
    }


    @GetMapping("/")
    fun index(
        @RequestParam(
            name = "confirmationValue", required = false
        ) confirmationValue: String?,
        modelMap: ModelMap
    ): String {
        log.info("get/index", "param confirmationValue is : $confirmationValue \n")
        try {
            var checkParams = CheckParams(confirmationValue ?: "");
            modelMap.addAttribute("checkParams", checkParams)
            return "index"
        } catch (e: ExceptionInInitializerError) {
            log.error("get/index", e)
        }
        return "error"
    }


    @PostMapping("/")
    fun check(
        @ModelAttribute("checkParams") checkParams: CheckParams,
        modelMap: ModelMap
    ): String {
        log.info("post/index", "param confirmationValue is :  ${checkParams.confirmationValue}\n")
        try {

            var pattern = "yyyy-MM-dd'T'HH:mm:ss.SSSZ"
            var sdformatter = SimpleDateFormat(pattern);
            var formattedConfirmations = mutableListOf<FormattedConfirmation>()

            var confirmations = confirmationRepository.findByValue(checkParams.confirmationValue)
            for(confirmation in confirmations) {
                val date = Date(confirmation.timestamp)
                val formattedTimestamp = sdformatter.format(date)
                var formattedConfirmation = FormattedConfirmation(
                    confirmation.algo.toString(),
                    confirmation.value.toString(),
                    formattedTimestamp
                )
                formattedConfirmations.add(formattedConfirmation)
            }

            modelMap.addAttribute("confirmations", formattedConfirmations)
            return "result"
        } catch (e: ExceptionInInitializerError) {
            log.error("post index", e)
        }
        return "error"
    }
}

data class CheckParams(var confirmationValue: String)

data class FormattedConfirmation(
    var algo: String,
    var value: String,
    var timestamp: String
    )
