/*
    Copyright (c) 2021 Richard Meinsen.

    This file is part of surec backend - prototype fund round 8 release.

    surec backend is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    surec backend is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

package eu.surec.backend.repositories

import eu.surec.backend.dto.Algo
import org.jetbrains.annotations.NotNull
import java.io.Serializable
import javax.persistence.*


@Entity
class ConfirmationEntity(

        @Id
        @GeneratedValue(strategy = GenerationType.IDENTITY)
        var id: Int = 0,

        @NotNull
        var value: String,

        @NotNull
        @Enumerated(EnumType.STRING)
        var algo: Algo? = null,

        @NotNull
        var timestamp: Long,

        @Column(nullable = true)
        @OneToMany(cascade = [CascadeType.ALL])
        var fingerprints: MutableList<FingerprintEntity>? = mutableListOf(),
) : Serializable {}


@Entity
class FingerprintEntity(
        @Id
        @GeneratedValue(strategy = GenerationType.IDENTITY)
        var id: Int = 0,

        @NotNull
        @Enumerated(EnumType.STRING)
        var algo : Algo,

        @NotNull
        var value: String,
) : Serializable { }



class ConfirmationEntityID(
        @NotNull
        @Id
        var confirmation: String? = null,

        @NotNull
        @Id
        var timestamp: Long = 0,
) : Serializable { }
